from rdflib import URIRef

# WARNING. This is a Generated File. Please do not edit.
# Please refer to the README at java/src/main/java/com/ncc/aif/ont2javagen for more information
# Last generated on: 08/24/2020 11:09:20
NAMESPACE = 'https://raw.githubusercontent.com/NextCenturyCorporation/AIDA-Interchange-Format/master/java/src/main/resources/com/ncc/aif/ontologies/EntityRelations#'

# Classes
Age = URIRef(NAMESPACE + 'Age')
Author = URIRef(NAMESPACE + 'Author')
Color = URIRef(NAMESPACE + 'Color')
Content = URIRef(NAMESPACE + 'Content')
Employment = URIRef(NAMESPACE + 'Employment')
Evaluate_Deliberateness_Accidental = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Accidental')
Evaluate_Deliberateness_Deliberate = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Deliberate')
Evaluate_Legitimacy_Illegitimate = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Illegitimate')
Evaluate_Legitimacy_Legitimate = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Legitimate')
Evaluate_Sentiment_Negative = URIRef(NAMESPACE + 'Evaluate.Sentiment.Negative')
Evaluate_Sentiment_Positive = URIRef(NAMESPACE + 'Evaluate.Sentiment.Positive')
Evaluation = URIRef(NAMESPACE + 'Evaluation')
Function = URIRef(NAMESPACE + 'Function')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_ControlTerritory = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.ControlTerritory')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_NationalityCitizen = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.NationalityCitizen')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_OwnershipPossession = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.OwnershipPossession')
GeneralAffiliation_MemberOriginReligionEthnicity = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity')
GeneralAffiliation_MemberOriginReligionEthnicity_Ethnicity = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.Ethnicity')
GeneralAffiliation_MemberOriginReligionEthnicity_NationalityCitizen = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.NationalityCitizen')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_NationalityCitizen = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation.NationalityCitizen')
GeneralAffiliation_OrganizationWebsite_OrganizationWebsite = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationWebsite.OrganizationWebsite')
GeneralAffiliation_Sponsorship = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship')
GeneralAffiliation_Sponsorship_AdvisePlanOrganize = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.AdvisePlanOrganize')
GeneralAffiliation_Sponsorship_Affiliated = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.Affiliated')
GeneralAffiliation_Sponsorship_HelpSupport = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.HelpSupport')
Information_Color_Color = URIRef(NAMESPACE + 'Information.Color.Color')
Information_Make_Make = URIRef(NAMESPACE + 'Information.Make.Make')
LocRel = URIRef(NAMESPACE + 'LocRel')
Make = URIRef(NAMESPACE + 'Make')
Material = URIRef(NAMESPACE + 'Material')
Measurement_Size = URIRef(NAMESPACE + 'Measurement.Size')
Measurement_Size_Count = URIRef(NAMESPACE + 'Measurement.Size.Count')
Measurement_Size_HeightLengthWidth = URIRef(NAMESPACE + 'Measurement.Size.HeightLengthWidth')
Measurement_Size_Percentage = URIRef(NAMESPACE + 'Measurement.Size.Percentage')
Measurement_Size_Weight = URIRef(NAMESPACE + 'Measurement.Size.Weight')
Medium = URIRef(NAMESPACE + 'Medium')
Nationality = URIRef(NAMESPACE + 'Nationality')
OrganizationAffiliation_EmploymentMembership = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership')
OrganizationAffiliation_EmploymentMembership_Employment = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Employment')
OrganizationAffiliation_EmploymentMembership_Membership = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Membership')
OrganizationAffiliation_Founder_Founder = URIRef(NAMESPACE + 'OrganizationAffiliation.Founder.Founder')
OrganizationAffiliation_Leadership = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership')
OrganizationAffiliation_Leadership_Government = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.Government')
OrganizationAffiliation_Leadership_HeadOfState = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.HeadOfState')
OrganizationAffiliation_Leadership_MilitaryPolice = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.MilitaryPolice')
PartWhole_Subsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary')
PartWhole_Subsidiary_NationalityCitizen = URIRef(NAMESPACE + 'PartWhole.Subsidiary.NationalityCitizen')
PartWhole_Subsidiary_OrganizationSubsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary.OrganizationSubsidiary')
PersonalSocial_Role = URIRef(NAMESPACE + 'PersonalSocial.Role')
PersonalSocial_Role_ProfessionalRole = URIRef(NAMESPACE + 'PersonalSocial.Role.ProfessionalRole')
PersonalSocial_Role_TitleFormOfAddress = URIRef(NAMESPACE + 'PersonalSocial.Role.TitleFormOfAddress')
PersonalSocial_Unspecified = URIRef(NAMESPACE + 'PersonalSocial.Unspecified')
PersonalSocial_Unspecified_Political = URIRef(NAMESPACE + 'PersonalSocial.Unspecified.Political')
Physical_LocatedNear = URIRef(NAMESPACE + 'Physical.LocatedNear')
Physical_LocatedNear_Surround = URIRef(NAMESPACE + 'Physical.LocatedNear.Surround')
Physical_OrganizationHeadquarters_OrganizationHeadquarters = URIRef(NAMESPACE + 'Physical.OrganizationHeadquarters.OrganizationHeadquarters')
Physical_Resident_Resident = URIRef(NAMESPACE + 'Physical.Resident.Resident')
ResponsibilityBlame_AssignBlame_AssignBlame = URIRef(NAMESPACE + 'ResponsibilityBlame.AssignBlame.AssignBlame')
ResponsibilityBlame_ClaimResponsibility_ClaimResponsibility = URIRef(NAMESPACE + 'ResponsibilityBlame.ClaimResponsibility.ClaimResponsibility')
Side = URIRef(NAMESPACE + 'Side')
Size = URIRef(NAMESPACE + 'Size')
Status = URIRef(NAMESPACE + 'Status')
Structure = URIRef(NAMESPACE + 'Structure')
Title = URIRef(NAMESPACE + 'Title')

# Properties
Age_Object = URIRef(NAMESPACE + 'Age_Object')
Age_Subject = URIRef(NAMESPACE + 'Age_Subject')
Author_Object = URIRef(NAMESPACE + 'Author_Object')
Author_Subject = URIRef(NAMESPACE + 'Author_Subject')
Color_Object = URIRef(NAMESPACE + 'Color_Object')
Color_Subject = URIRef(NAMESPACE + 'Color_Subject')
Content_Object = URIRef(NAMESPACE + 'Content_Object')
Content_Subject = URIRef(NAMESPACE + 'Content_Subject')
Employment_Object = URIRef(NAMESPACE + 'Employment_Object')
Employment_Subject = URIRef(NAMESPACE + 'Employment_Subject')
Evaluate_Deliberateness_Accidental_Event = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Accidental_Event')
Evaluate_Deliberateness_Accidental_Holder = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Accidental_Holder')
Evaluate_Deliberateness_Deliberate_Event = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Deliberate_Event')
Evaluate_Deliberateness_Deliberate_Holder = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Deliberate_Holder')
Evaluate_Legitimacy_Illegitimate_Event = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Illegitimate_Event')
Evaluate_Legitimacy_Illegitimate_Holder = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Illegitimate_Holder')
Evaluate_Legitimacy_Legitimate_Event = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Legitimate_Event')
Evaluate_Legitimacy_Legitimate_Holder = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Legitimate_Holder')
Evaluate_Sentiment_Negative_Holder = URIRef(NAMESPACE + 'Evaluate.Sentiment.Negative_Holder')
Evaluate_Sentiment_Negative_SentimentTarget = URIRef(NAMESPACE + 'Evaluate.Sentiment.Negative_SentimentTarget')
Evaluate_Sentiment_Positive_Holder = URIRef(NAMESPACE + 'Evaluate.Sentiment.Positive_Holder')
Evaluate_Sentiment_Positive_SentimentTarget = URIRef(NAMESPACE + 'Evaluate.Sentiment.Positive_SentimentTarget')
Evaluation_Object = URIRef(NAMESPACE + 'Evaluation_Object')
Evaluation_Subject = URIRef(NAMESPACE + 'Evaluation_Subject')
Function_Object = URIRef(NAMESPACE + 'Function_Object')
Function_Subject = URIRef(NAMESPACE + 'Function_Subject')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_Artifact = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation_Artifact')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_ControlTerritory_Controller = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.ControlTerritory_Controller')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_ControlTerritory_Territory = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.ControlTerritory_Territory')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_EntityOrFiller = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation_EntityOrFiller')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_NationalityCitizen_Artifact = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.NationalityCitizen_Artifact')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_NationalityCitizen_Nationality = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.NationalityCitizen_Nationality')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_OwnershipPossession_Artifact = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.OwnershipPossession_Artifact')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_OwnershipPossession_Owner = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.OwnershipPossession_Owner')
GeneralAffiliation_MemberOriginReligionEthnicity_EntityOrFiller = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity_EntityOrFiller')
GeneralAffiliation_MemberOriginReligionEthnicity_Ethnicity_Ethnicity = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.Ethnicity_Ethnicity')
GeneralAffiliation_MemberOriginReligionEthnicity_Ethnicity_Person = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.Ethnicity_Person')
GeneralAffiliation_MemberOriginReligionEthnicity_NationalityCitizen_Citizen = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.NationalityCitizen_Citizen')
GeneralAffiliation_MemberOriginReligionEthnicity_NationalityCitizen_Nationality = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.NationalityCitizen_Nationality')
GeneralAffiliation_MemberOriginReligionEthnicity_Person = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity_Person')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_EntityOrFiller = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation_EntityOrFiller')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_NationalityCitizen_Nationality = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation.NationalityCitizen_Nationality')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_NationalityCitizen_Organization = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation.NationalityCitizen_Organization')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_Organization = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation_Organization')
GeneralAffiliation_OrganizationWebsite_OrganizationWebsite_Organization = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationWebsite.OrganizationWebsite_Organization')
GeneralAffiliation_OrganizationWebsite_OrganizationWebsite_Website = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationWebsite.OrganizationWebsite_Website')
GeneralAffiliation_Sponsorship_ActorOrEvent = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship_ActorOrEvent')
GeneralAffiliation_Sponsorship_AdvisePlanOrganize_ActorOrEvent = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.AdvisePlanOrganize_ActorOrEvent')
GeneralAffiliation_Sponsorship_AdvisePlanOrganize_Sponsor = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.AdvisePlanOrganize_Sponsor')
GeneralAffiliation_Sponsorship_Affiliated_ActorOrEvent = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.Affiliated_ActorOrEvent')
GeneralAffiliation_Sponsorship_Affiliated_Sponsor = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.Affiliated_Sponsor')
GeneralAffiliation_Sponsorship_HelpSupport_ActorOrEvent = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.HelpSupport_ActorOrEvent')
GeneralAffiliation_Sponsorship_HelpSupport_Sponsor = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.HelpSupport_Sponsor')
GeneralAffiliation_Sponsorship_Sponsor = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship_Sponsor')
Information_Color_Color_Color = URIRef(NAMESPACE + 'Information.Color.Color_Color')
Information_Color_Color_EntityOrFiller = URIRef(NAMESPACE + 'Information.Color.Color_EntityOrFiller')
Information_Make_Make_Brand = URIRef(NAMESPACE + 'Information.Make.Make_Brand')
Information_Make_Make_EntityOrFiller = URIRef(NAMESPACE + 'Information.Make.Make_EntityOrFiller')
LocRel_Object = URIRef(NAMESPACE + 'LocRel_Object')
LocRel_Subject = URIRef(NAMESPACE + 'LocRel_Subject')
Make_Object = URIRef(NAMESPACE + 'Make_Object')
Make_Subject = URIRef(NAMESPACE + 'Make_Subject')
Material_Object = URIRef(NAMESPACE + 'Material_Object')
Material_Subject = URIRef(NAMESPACE + 'Material_Subject')
Measurement_Size_Count_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size.Count_EntityOrFiller')
Measurement_Size_Count_Measurement = URIRef(NAMESPACE + 'Measurement.Size.Count_Measurement')
Measurement_Size_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size_EntityOrFiller')
Measurement_Size_HeightLengthWidth_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size.HeightLengthWidth_EntityOrFiller')
Measurement_Size_HeightLengthWidth_Measurement = URIRef(NAMESPACE + 'Measurement.Size.HeightLengthWidth_Measurement')
Measurement_Size_Measurement = URIRef(NAMESPACE + 'Measurement.Size_Measurement')
Measurement_Size_Percentage_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size.Percentage_EntityOrFiller')
Measurement_Size_Percentage_Measurement = URIRef(NAMESPACE + 'Measurement.Size.Percentage_Measurement')
Measurement_Size_Weight_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size.Weight_EntityOrFiller')
Measurement_Size_Weight_Measurement = URIRef(NAMESPACE + 'Measurement.Size.Weight_Measurement')
Medium_Object = URIRef(NAMESPACE + 'Medium_Object')
Medium_Subject = URIRef(NAMESPACE + 'Medium_Subject')
Nationality_Object = URIRef(NAMESPACE + 'Nationality_Object')
Nationality_Subject = URIRef(NAMESPACE + 'Nationality_Subject')
OrganizationAffiliation_EmploymentMembership_EmployeeMember = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership_EmployeeMember')
OrganizationAffiliation_EmploymentMembership_Employment_Employee = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Employment_Employee')
OrganizationAffiliation_EmploymentMembership_Employment_PlaceOfEmployment = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Employment_PlaceOfEmployment')
OrganizationAffiliation_EmploymentMembership_Membership_Member = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Membership_Member')
OrganizationAffiliation_EmploymentMembership_Membership_PlaceOfMembership = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Membership_PlaceOfMembership')
OrganizationAffiliation_EmploymentMembership_PlaceOfEmploymentMembership = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership_PlaceOfEmploymentMembership')
OrganizationAffiliation_Founder_Founder_Founder = URIRef(NAMESPACE + 'OrganizationAffiliation.Founder.Founder_Founder')
OrganizationAffiliation_Founder_Founder_Organization = URIRef(NAMESPACE + 'OrganizationAffiliation.Founder.Founder_Organization')
OrganizationAffiliation_Leadership_Government_GovernmentBodyOrGPE = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.Government_GovernmentBodyOrGPE')
OrganizationAffiliation_Leadership_Government_Leader = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.Government_Leader')
OrganizationAffiliation_Leadership_HeadOfState_Country = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.HeadOfState_Country')
OrganizationAffiliation_Leadership_HeadOfState_Leader = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.HeadOfState_Leader')
OrganizationAffiliation_Leadership_Leader = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership_Leader')
OrganizationAffiliation_Leadership_MilitaryPolice_Leader = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.MilitaryPolice_Leader')
OrganizationAffiliation_Leadership_MilitaryPolice_MilitaryPoliceORG = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.MilitaryPolice_MilitaryPoliceORG')
OrganizationAffiliation_Leadership_Organization = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership_Organization')
PartWhole_Subsidiary_NationalityCitizen_Parent = URIRef(NAMESPACE + 'PartWhole.Subsidiary.NationalityCitizen_Parent')
PartWhole_Subsidiary_NationalityCitizen_Subsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary.NationalityCitizen_Subsidiary')
PartWhole_Subsidiary_OrganizationSubsidiary_Parent = URIRef(NAMESPACE + 'PartWhole.Subsidiary.OrganizationSubsidiary_Parent')
PartWhole_Subsidiary_OrganizationSubsidiary_Subsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary.OrganizationSubsidiary_Subsidiary')
PartWhole_Subsidiary_Parent = URIRef(NAMESPACE + 'PartWhole.Subsidiary_Parent')
PartWhole_Subsidiary_Subsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary_Subsidiary')
PersonalSocial_Role_Person = URIRef(NAMESPACE + 'PersonalSocial.Role_Person')
PersonalSocial_Role_ProfessionalRole_JobRole = URIRef(NAMESPACE + 'PersonalSocial.Role.ProfessionalRole_JobRole')
PersonalSocial_Role_ProfessionalRole_Person = URIRef(NAMESPACE + 'PersonalSocial.Role.ProfessionalRole_Person')
PersonalSocial_Role_Role = URIRef(NAMESPACE + 'PersonalSocial.Role_Role')
PersonalSocial_Role_TitleFormOfAddress_Person = URIRef(NAMESPACE + 'PersonalSocial.Role.TitleFormOfAddress_Person')
PersonalSocial_Role_TitleFormOfAddress_Title = URIRef(NAMESPACE + 'PersonalSocial.Role.TitleFormOfAddress_Title')
PersonalSocial_Unspecified_Person = URIRef(NAMESPACE + 'PersonalSocial.Unspecified_Person')
PersonalSocial_Unspecified_Political_Person = URIRef(NAMESPACE + 'PersonalSocial.Unspecified.Political_Person')
Physical_LocatedNear_EntityOrFiller = URIRef(NAMESPACE + 'Physical.LocatedNear_EntityOrFiller')
Physical_LocatedNear_Place = URIRef(NAMESPACE + 'Physical.LocatedNear_Place')
Physical_LocatedNear_Surround_EntityOrFiller = URIRef(NAMESPACE + 'Physical.LocatedNear.Surround_EntityOrFiller')
Physical_LocatedNear_Surround_Place = URIRef(NAMESPACE + 'Physical.LocatedNear.Surround_Place')
Physical_OrganizationHeadquarters_OrganizationHeadquarters_Organization = URIRef(NAMESPACE + 'Physical.OrganizationHeadquarters.OrganizationHeadquarters_Organization')
Physical_OrganizationHeadquarters_OrganizationHeadquarters_Place = URIRef(NAMESPACE + 'Physical.OrganizationHeadquarters.OrganizationHeadquarters_Place')
Physical_Resident_Resident_Place = URIRef(NAMESPACE + 'Physical.Resident.Resident_Place')
Physical_Resident_Resident_Resident = URIRef(NAMESPACE + 'Physical.Resident.Resident_Resident')
ResponsibilityBlame_AssignBlame_AssignBlame_EntityResponsible = URIRef(NAMESPACE + 'ResponsibilityBlame.AssignBlame.AssignBlame_EntityResponsible')
ResponsibilityBlame_AssignBlame_AssignBlame_Event = URIRef(NAMESPACE + 'ResponsibilityBlame.AssignBlame.AssignBlame_Event')
ResponsibilityBlame_ClaimResponsibility_ClaimResponsibility_EntityResponsible = URIRef(NAMESPACE + 'ResponsibilityBlame.ClaimResponsibility.ClaimResponsibility_EntityResponsible')
ResponsibilityBlame_ClaimResponsibility_ClaimResponsibility_Event = URIRef(NAMESPACE + 'ResponsibilityBlame.ClaimResponsibility.ClaimResponsibility_Event')
Side_Object = URIRef(NAMESPACE + 'Side_Object')
Side_Subject = URIRef(NAMESPACE + 'Side_Subject')
Size_Object = URIRef(NAMESPACE + 'Size_Object')
Size_Subject = URIRef(NAMESPACE + 'Size_Subject')
Status_Object = URIRef(NAMESPACE + 'Status_Object')
Status_Subject = URIRef(NAMESPACE + 'Status_Subject')
Structure_Object = URIRef(NAMESPACE + 'Structure_Object')
Structure_Subject = URIRef(NAMESPACE + 'Structure_Subject')
Title_Object = URIRef(NAMESPACE + 'Title_Object')
Title_Subject = URIRef(NAMESPACE + 'Title_Subject')
