from rdflib import URIRef

# WARNING. This is a Generated File. Please do not edit.
# Please refer to the README at java/src/main/java/com/ncc/aif/ont2javagen for more information
# Last generated on: 08/24/2020 11:09:20
NAMESPACE = 'https://raw.githubusercontent.com/NextCenturyCorporation/AIDA-Interchange-Format/master/java/src/main/resources/com/ncc/aif/ontologies/InterchangeOntology#'

# Classes
AudioJustification = URIRef(NAMESPACE + 'AudioJustification')
BoundingBox = URIRef(NAMESPACE + 'BoundingBox')
ClusterMembership = URIRef(NAMESPACE + 'ClusterMembership')
CompoundJustification = URIRef(NAMESPACE + 'CompoundJustification')
Confidence = URIRef(NAMESPACE + 'Confidence')
Entity = URIRef(NAMESPACE + 'Entity')
Event = URIRef(NAMESPACE + 'Event')
Hypothesis = URIRef(NAMESPACE + 'Hypothesis')
ImageJustification = URIRef(NAMESPACE + 'ImageJustification')
Justification = URIRef(NAMESPACE + 'Justification')
JustificationTypes = URIRef(NAMESPACE + 'JustificationTypes')
KeyFrameVideoJustification = URIRef(NAMESPACE + 'KeyFrameVideoJustification')
LDCTime = URIRef(NAMESPACE + 'LDCTime')
LDCTimeComponent = URIRef(NAMESPACE + 'LDCTimeComponent')
LinkAssertion = URIRef(NAMESPACE + 'LinkAssertion')
MutualExclusion = URIRef(NAMESPACE + 'MutualExclusion')
MutualExclusionAlternative = URIRef(NAMESPACE + 'MutualExclusionAlternative')
PrivateData = URIRef(NAMESPACE + 'PrivateData')
Relation = URIRef(NAMESPACE + 'Relation')
SameAsCluster = URIRef(NAMESPACE + 'SameAsCluster')
ShotVideoJustification = URIRef(NAMESPACE + 'ShotVideoJustification')
Subgraph = URIRef(NAMESPACE + 'Subgraph')
System = URIRef(NAMESPACE + 'System')
TextJustification = URIRef(NAMESPACE + 'TextJustification')
VideoJustification = URIRef(NAMESPACE + 'VideoJustification')
VideoJustificationChannel = URIRef(NAMESPACE + 'VideoJustificationChannel')

# Individuals
VideoJustificationChannelBoth = URIRef(NAMESPACE + 'VideoJustificationChannelBoth')
VideoJustificationChannelPicture = URIRef(NAMESPACE + 'VideoJustificationChannelPicture')
VideoJustificationChannelSound = URIRef(NAMESPACE + 'VideoJustificationChannelSound')

# Properties
alternative = URIRef(NAMESPACE + 'alternative')
alternativeGraph = URIRef(NAMESPACE + 'alternativeGraph')
boundingBox = URIRef(NAMESPACE + 'boundingBox')
boundingBoxLowerRightX = URIRef(NAMESPACE + 'boundingBoxLowerRightX')
boundingBoxLowerRightY = URIRef(NAMESPACE + 'boundingBoxLowerRightY')
boundingBoxUpperLeftX = URIRef(NAMESPACE + 'boundingBoxUpperLeftX')
boundingBoxUpperLeftY = URIRef(NAMESPACE + 'boundingBoxUpperLeftY')
channel = URIRef(NAMESPACE + 'channel')
cluster = URIRef(NAMESPACE + 'cluster')
clusterMember = URIRef(NAMESPACE + 'clusterMember')
confidence = URIRef(NAMESPACE + 'confidence')
confidenceValue = URIRef(NAMESPACE + 'confidenceValue')
containedJustification = URIRef(NAMESPACE + 'containedJustification')
day = URIRef(NAMESPACE + 'day')
dependsOnHypothesis = URIRef(NAMESPACE + 'dependsOnHypothesis')
end = URIRef(NAMESPACE + 'end')
endOffsetInclusive = URIRef(NAMESPACE + 'endOffsetInclusive')
endTimestamp = URIRef(NAMESPACE + 'endTimestamp')
handle = URIRef(NAMESPACE + 'handle')
hasName = URIRef(NAMESPACE + 'hasName')
hypothesisContent = URIRef(NAMESPACE + 'hypothesisContent')
importance = URIRef(NAMESPACE + 'importance')
informativeJustification = URIRef(NAMESPACE + 'informativeJustification')
jsonContent = URIRef(NAMESPACE + 'jsonContent')
justifiedBy = URIRef(NAMESPACE + 'justifiedBy')
keyFrame = URIRef(NAMESPACE + 'keyFrame')
ldcTime = URIRef(NAMESPACE + 'ldcTime')
link = URIRef(NAMESPACE + 'link')
linkTarget = URIRef(NAMESPACE + 'linkTarget')
month = URIRef(NAMESPACE + 'month')
noneOfTheAbove = URIRef(NAMESPACE + 'noneOfTheAbove')
numericValue = URIRef(NAMESPACE + 'numericValue')
privateData = URIRef(NAMESPACE + 'privateData')
prototype = URIRef(NAMESPACE + 'prototype')
shot = URIRef(NAMESPACE + 'shot')
source = URIRef(NAMESPACE + 'source')
sourceDocument = URIRef(NAMESPACE + 'sourceDocument')
start = URIRef(NAMESPACE + 'start')
startOffset = URIRef(NAMESPACE + 'startOffset')
startTimestamp = URIRef(NAMESPACE + 'startTimestamp')
subgraphContains = URIRef(NAMESPACE + 'subgraphContains')
system = URIRef(NAMESPACE + 'system')
textValue = URIRef(NAMESPACE + 'textValue')
timeType = URIRef(NAMESPACE + 'timeType')
year = URIRef(NAMESPACE + 'year')
