from rdflib import URIRef

# WARNING. This is a Generated File. Please do not edit.
# Please refer to the README at java/src/main/java/com/ncc/aif/ont2javagen for more information
# Last generated on: 08/24/2020 11:09:20
NAMESPACE = 'https://raw.githubusercontent.com/NextCenturyCorporation/AIDA-Interchange-Format/master/java/src/main/resources/com/ncc/aif/ontologies/AidaDomainOntologiesCommon#'

# Classes
CanHaveName = URIRef(NAMESPACE + 'CanHaveName')
CanHaveNumericValue = URIRef(NAMESPACE + 'CanHaveNumericValue')
CanHaveTextValue = URIRef(NAMESPACE + 'CanHaveTextValue')
EntityType = URIRef(NAMESPACE + 'EntityType')
EventArgumentType = URIRef(NAMESPACE + 'EventArgumentType')
EventType = URIRef(NAMESPACE + 'EventType')
RelationArgumentType = URIRef(NAMESPACE + 'RelationArgumentType')
RelationType = URIRef(NAMESPACE + 'RelationType')
